@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 mod nrs_map;
 
@@ -225,8 +224,7 @@ impl Safe {
             Err(Error::EmptyContent(_)) => Ok(BTreeSet::new()),
             Err(Error::ContentNotFound(e)) => Err(Error::ContentNotFound(format!(
                 "No Nrs Map entry found at {}: {}",
-                safe_url.to_string(),
-                e
+                safe_url, e
             ))),
             Err(e) => Err(Error::NetDataError(format!(
                 "Failed to get Nrs Map entries: {}",
@@ -344,12 +342,12 @@ fn validate_nrs_url(link: &SafeUrl) -> Result<()> {
         {
             return Err(Error::UnversionedContentError(format!(
                 "The linked content ({}) is versionable, therefore NRS requires the link to specify a hash: {}",
-                content_type, link.to_string()
+                content_type, link
             )));
         } else if data_type == DataType::Register {
             return Err(Error::UnversionedContentError(format!(
                 "The linked content ({}) is versionable, therefore NRS requires the link to specify a hash: {}",
-                data_type, link.to_string()
+                data_type, link
             )));
         }
     }
