@@ -1,3 +1,11 @@
+// Copyright 2022 MaidSafe.net limited.
+//
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
+
 use super::{Range, SafeData};
 use crate::app::{
     files::{self, FileInfo, FilesMap},
@@ -105,7 +113,7 @@ impl Safe {
                 };
                 Ok(safe_data)
             }
-            DataType::Bytes => {
+            DataType::File => {
                 self.retrieve_data(&input_url, retrieve_data, None, &metadata, range)
                     .await
             }
@@ -148,7 +156,7 @@ impl Safe {
         ensure_no_subnames(&input_url, "media type")?;
 
         match input_url.data_type() {
-            DataType::Bytes => {
+            DataType::File => {
                 self.retrieve_data(
                     &input_url,
                     retrieve_data,
@@ -207,11 +215,10 @@ impl Safe {
 
             // try to gather file link and metadata for a file
             let (link, metadata) = files::get_file_link_and_metadata(&files_map_for_path, &path)
-                .map_err(|e| {
+                .map_err(|err| {
                     Error::ContentError(format!(
                         "Failed to obtain file link or info on FileContainer at: {}: {}",
-                        input_url,
-                        e.to_string(),
+                        input_url, err,
                     ))
                 })?;
 
@@ -263,7 +270,7 @@ impl Safe {
             Bytes::new()
         };
 
-        let safe_data = SafeData::PublicBlob {
+        let safe_data = SafeData::PublicFile {
             xorurl: input_url.to_xorurl_string(),
             xorname: input_url.xorname(),
             data,
