@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use super::resolver::Range;
 use crate::{ipc::NodeConfig, Error, Result};
@@ -13,6 +12,7 @@ use bytes::Bytes;
 use hex::encode;
 use log::{debug, info};
 use safe_network::client::{Client, ClientConfig, Error as ClientError, RegisterWriteAheadLog};
+use safe_network::types::register::{Policy, PrivatePolicy, PublicPolicy};
 use safe_network::types::{
     register::{Entry, EntryHash, PrivatePermissions, PublicPermissions, User},
     BytesAddress, Error as SafeNdError, Keypair, RegisterAddress, Scope,
@@ -95,7 +95,7 @@ impl SafeAppClient {
     }
 
     //
-    // Blob operations
+    // File operations
     //
     pub async fn store_bytes(&self, bytes: Bytes, dry_run: bool) -> Result<XorName> {
         let address = if dry_run {
@@ -126,7 +126,7 @@ impl SafeAppClient {
         } else {
             client.read_bytes(address).await
         }
-        .map_err(|e| Error::NetDataError(format!("Failed to GET Blob: {:?}", e)))?;
+        .map_err(|e| Error::NetDataError(format!("Failed to GET file: {:?}", e)))?;
 
         debug!(
             "{} bytes of data successfully retrieved from: {:?}",
@@ -167,16 +167,12 @@ impl SafeAppClient {
         info!("Xorname for new Register storage: {:?}", &xorname);
 
         // The Register's owner will be the client's public key
-        let my_pk = client.public_key();
+        let my_pk = User::Key(client.public_key());
 
         // Store the Register on the network
         let (_, op_batch) = if private {
-            // Set read and write  permissions to this application
-            let mut perms = BTreeMap::default();
-            let _ = perms.insert(my_pk, PrivatePermissions::new(true, true));
-
             client
-                .store_private_register(xorname, tag, my_pk, perms)
+                .create_register(xorname, tag, private_policy(my_pk))
                 .await
                 .map_err(|e| {
                     Error::NetDataError(format!(
@@ -186,12 +182,10 @@ impl SafeAppClient {
                 })?
         } else {
             // Set write permissions to this application
-            let user_app = User::Key(my_pk);
-            let mut perms = BTreeMap::default();
-            let _ = perms.insert(user_app, PublicPermissions::new(true));
+            let user_app = my_pk;
 
             client
-                .store_public_register(xorname, tag, my_pk, perms)
+                .create_register(xorname, tag, public_policy(user_app))
                 .await
                 .map_err(|e| {
                     Error::NetDataError(format!(
@@ -204,7 +198,7 @@ impl SafeAppClient {
         Ok((xorname, op_batch))
     }
 
-    /// Low level method to read all register entries
+    /// Low level method to read latest register entries
     pub async fn read_register(
         &self,
         address: RegisterAddress,
@@ -238,7 +232,11 @@ impl SafeAppClient {
             .get_register_entry(address, hash)
             .await
             .map_err(|err| {
-                if let ClientError::NetworkDataError(SafeNdError::NoSuchEntry) = err {
+                if let ClientError::ErrorMessage {
+                    source: safe_network::messaging::data::Error::NoSuchEntry,
+                    ..
+                } = err
+                {
                     Error::HashNotFound(hash)
                 } else {
                     Error::NetDataError(format!(
@@ -282,3 +280,15 @@ impl SafeAppClient {
         Ok(())
     }
 }
+
+fn private_policy(owner: User) -> Policy {
+    let mut permissions = BTreeMap::new();
+    let _ = permissions.insert(owner, PrivatePermissions::new(true, true));
+    Policy::Private(PrivatePolicy { owner, permissions })
+}
+
+fn public_policy(owner: User) -> Policy {
+    let mut permissions = BTreeMap::new();
+    let _ = permissions.insert(owner, PublicPermissions::new(true));
+    Policy::Public(PublicPolicy { owner, permissions })
+}
